@@ -26,8 +26,7 @@ from typing import TYPE_CHECKING, Any
 import requests
 from pydruid.db import connect
 
-from airflow.exceptions import AirflowException
-from airflow.providers.common.compat.sdk import BaseHook
+from airflow.providers.common.compat.sdk import AirflowException, BaseHook
 from airflow.providers.common.sql.hooks.sql import DbApiHook
 
 if TYPE_CHECKING:
